Learn R Programming

planningML (version 1.0.1)

fit_learningcurve: Generate descriptive summary for objects returned by functions in EHRsampling

Description

Generate descriptive summary for objects returned by functions in EHRsampling.

Usage

fit_learningcurve(df, testX, target = NULL)

Value

fit_learningcurve() returns the estimated power law model for the learning curve.

Arguments

df

data for learning curve fitting; first column is sample size, second column is AUC measurement.

testX

test data for prediction

target

target MCC/AUC that you want to achieve