Generate descriptive summary for objects returned by functions in EHRsampling.
fit_learningcurve(df, testX, target = NULL)fit_learningcurve() returns the estimated power law model for the learning curve.
data for learning curve fitting; first column is sample size, second column is AUC measurement.
test data for prediction
target MCC/AUC that you want to achieve